@@ -5,10 +5,9 @@
 import numpy as np
 
 colormap_names = [
-    'Autumn', 'Bone', 'Cold', 'Disparity',
-    'Earth', 'Grayscale', 'Hot', 'HSV', 'Inferno', 'Jet',
-    'Magma', 'Parula', 'Pastel', 'Plasma', 'Sepia',
-    'Temperature', 'Thermal', 'Turbo', 'Viridis'
+    'Autumn', 'Bone', 'Cold', 'Disparity', 'Earth', 'Grayscale', 'Hot', 'HSV',
+    'Inferno', 'Jet', 'Magma', 'Pastel', 'Plasma', 'Sepia', 'Temperature',
+    'Thermal', 'Turbo', 'Viridis'
 ]
 
 
@@ -131,6 +130,7 @@ colormap_autumn_bgr = [
     (0, 246, 255), (0, 247, 255), (0, 248, 255), (0, 249, 255), (0, 250, 255), (0, 251, 255),
     (0, 252, 255), (0, 253, 255), (0, 254, 255), (0, 255, 255)]
 colormap_autumn_rgb = [(c[2], c[1], c[0]) for c in colormap_autumn_bgr]
+autumn = colormap_autumn_rgb
 
 colormap_bone_bgr = [
     (0, 0, 0), (1, 1, 1), (2, 2, 2), (4, 3, 3), (5, 4, 4), (6, 4, 4),
@@ -177,6 +177,7 @@ colormap_bone_bgr = [
     (247, 247, 243), (248, 248, 244), (249, 249, 245), (250, 250, 247), (251, 251, 248), (251, 251, 250),
     (252, 252, 251), (253, 253, 252), (254, 254, 254), (255, 255, 255)]
 colormap_bone_rgb = [(c[2], c[1], c[0]) for c in colormap_bone_bgr]
+bone = colormap_bone_rgb
 
 colormap_cold_bgr = [
     (0, 0, 0), (3, 0, 0), (6, 0, 0), (9, 0, 0), (12, 0, 0), (15, 0, 0),
@@ -223,6 +224,7 @@ colormap_cold_bgr = [
     (255, 255, 228), (255, 255, 231), (255, 255, 234), (255, 255, 237), (255, 255, 240), (255, 255, 243),
     (255, 255, 246), (255, 255, 249), (255, 255, 252), (255, 255, 255)]
 colormap_cold_rgb = [(c[2], c[1], c[0]) for c in colormap_cold_bgr]
+cold = colormap_cold_rgb
 
 colormap_disparity_bgr = [
     (0, 0, 0), (9, 0, 0), (18, 0, 0), (26, 0, 0), (35, 0, 0), (44, 0, 0),
@@ -269,6 +271,7 @@ colormap_disparity_bgr = [
     (176, 255, 255), (185, 255, 255), (194, 255, 255), (202, 255, 255), (211, 255, 255), (220, 255, 255),
     (229, 255, 255), (237, 255, 255), (246, 255, 255), (255, 255, 255)]
 colormap_disparity_rgb = [(c[2], c[1], c[0]) for c in colormap_disparity_bgr]
+disparity = colormap_disparity_rgb
 
 colormap_earth_bgr = [
     (0, 0, 0), (1, 2, 0), (2, 3, 0), (2, 5, 0), (3, 6, 0), (4, 8, 0),
@@ -315,6 +318,7 @@ colormap_earth_bgr = [
     (227, 245, 255), (230, 246, 255), (233, 247, 255), (237, 248, 255), (240, 249, 255), (243, 251, 255),
     (246, 252, 255), (249, 253, 255), (252, 254, 255), (255, 255, 255)]
 colormap_earth_rgb = [(c[2], c[1], c[0]) for c in colormap_earth_bgr]
+earth = colormap_earth_rgb
 
 colormap_gray = [
     (0, 0, 0), (1, 1, 1), (2, 2, 2), (3, 3, 3), (4, 4, 4), (5, 5, 5),
@@ -360,6 +364,7 @@ colormap_gray = [
     (240, 240, 240), (241, 241, 241), (242, 242, 242), (243, 243, 243), (244, 244, 244), (245, 245, 245),
     (246, 246, 246), (247, 247, 247), (248, 248, 248), (249, 249, 249), (250, 250, 250), (251, 251, 251),
     (252, 252, 252), (253, 253, 253), (254, 254, 254), (255, 255, 255)]
+gray = colormap_gray
 
 colormap_hot_bgr = [
     (0, 0, 0), (0, 0, 3), (0, 0, 5), (0, 0, 8), (0, 0, 11), (0, 0, 13),
@@ -406,6 +411,7 @@ colormap_hot_bgr = [
     (219, 255, 255), (223, 255, 255), (227, 255, 255), (231, 255, 255), (235, 255, 255), (239, 255, 255),
     (243, 255, 255), (247, 255, 255), (251, 255, 255), (255, 255, 255)]
 colormap_hot_rgb = [(c[2], c[1], c[0]) for c in colormap_hot_bgr]
+hot = colormap_hot_rgb
 
 colormap_hsv_bgr = [
     (0, 0, 255), (0, 6, 255), (0, 12, 255), (0, 18, 255), (0, 24, 255), (0, 30, 255),
@@ -452,6 +458,7 @@ colormap_hsv_bgr = [
     (54, 0, 255), (48, 0, 255), (42, 0, 255), (36, 0, 255), (30, 0, 255), (24, 0, 255),
     (18, 0, 255), (12, 0, 255), (6, 0, 255), (0, 0, 255)]
 colormap_hsv_rgb = [(c[2], c[1], c[0]) for c in colormap_hsv_bgr]
+hsv = colormap_hsv_rgb
 
 colormap_inferno_bgr = [
     (4, 0, 0), (5, 0, 1), (6, 1, 1), (8, 1, 1), (10, 1, 2), (12, 2, 2),
@@ -498,6 +505,7 @@ colormap_inferno_bgr = [
     (130, 244, 242), (134, 245, 243), (138, 246, 243), (142, 248, 244), (146, 249, 245), (150, 250, 246),
     (154, 251, 248), (157, 252, 249), (161, 253, 250), (164, 255, 252)]
 colormap_inferno_rgb = [(c[2], c[1], c[0]) for c in colormap_inferno_bgr]
+inferno = colormap_inferno_rgb
 
 colormap_jet_bgr = [
     (128, 0, 0), (132, 0, 0), (136, 0, 0), (140, 0, 0), (144, 0, 0), (147, 0, 0),
@@ -544,6 +552,7 @@ colormap_jet_bgr = [
     (0, 0, 163), (0, 0, 160), (0, 0, 156), (0, 0, 152), (0, 0, 148), (0, 0, 144),
     (0, 0, 139), (0, 0, 135), (0, 0, 132), (0, 0, 128)]
 colormap_jet_rgb = [(c[2], c[1], c[0]) for c in colormap_jet_bgr]
+jet = colormap_jet_rgb
 
 colormap_magma_bgr = [
     (4, 0, 0), (5, 0, 1), (6, 1, 1), (8, 1, 1), (9, 1, 2), (11, 2, 2),
@@ -590,52 +599,7 @@ colormap_magma_bgr = [
     (174, 236, 252), (176, 238, 252), (178, 240, 252), (180, 242, 252), (182, 244, 252), (184, 246, 252),
     (185, 247, 252), (187, 249, 252), (189, 251, 252), (191, 253, 252)]
 colormap_magma_rgb = [(c[2], c[1], c[0]) for c in colormap_magma_bgr]
-
-colormap_parula_bgr = [
-    (168, 38, 62), (172, 39, 62), (175, 40, 63), (178, 41, 63), (180, 42, 64), (183, 43, 64),
-    (186, 44, 65), (189, 45, 65), (191, 46, 66), (194, 47, 66), (197, 48, 67), (200, 49, 67),
-    (202, 50, 67), (205, 51, 68), (208, 52, 68), (210, 53, 69), (213, 55, 69), (215, 56, 69),
-    (217, 57, 70), (220, 58, 70), (222, 59, 70), (224, 61, 70), (225, 62, 71), (227, 63, 71),
-    (229, 65, 71), (230, 66, 71), (232, 68, 71), (233, 69, 71), (235, 70, 71), (236, 72, 72),
-    (237, 73, 72), (238, 75, 72), (240, 76, 72), (241, 78, 72), (242, 79, 72), (243, 80, 72),
-    (244, 82, 72), (245, 83, 72), (246, 84, 72), (247, 86, 71), (247, 87, 71), (248, 89, 71),
-    (249, 90, 71), (250, 91, 71), (250, 93, 71), (251, 94, 70), (251, 96, 70), (252, 97, 70),
-    (252, 98, 69), (253, 100, 69), (253, 101, 68), (253, 103, 67), (254, 104, 67), (254, 106, 66),
-    (254, 107, 65), (254, 109, 64), (255, 110, 63), (255, 112, 62), (255, 113, 60), (255, 115, 59),
-    (255, 116, 57), (254, 118, 56), (254, 119, 54), (253, 121, 53), (253, 122, 51), (252, 124, 50),
-    (252, 125, 49), (251, 127, 48), (250, 128, 47), (250, 130, 47), (249, 131, 46), (248, 132, 46),
-    (248, 134, 46), (247, 135, 46), (246, 136, 45), (245, 138, 45), (244, 139, 45), (243, 140, 45),
-    (242, 142, 45), (241, 143, 44), (240, 144, 44), (239, 145, 43), (238, 147, 42), (237, 148, 41),
-    (236, 149, 40), (235, 151, 39), (234, 152, 39), (233, 153, 38), (232, 154, 38), (232, 155, 37),
-    (231, 156, 37), (230, 158, 36), (229, 159, 36), (229, 160, 35), (228, 161, 35), (228, 162, 34),
-    (227, 163, 33), (227, 165, 32), (226, 166, 31), (225, 167, 30), (225, 168, 29), (224, 169, 29),
-    (223, 170, 28), (222, 171, 27), (221, 172, 26), (220, 173, 25), (218, 174, 23), (217, 175, 22),
-    (216, 176, 20), (214, 177, 18), (213, 178, 16), (212, 179, 14), (210, 179, 11), (209, 180, 8),
-    (207, 181, 6), (206, 182, 4), (204, 183, 2), (202, 183, 1), (201, 184, 0), (199, 185, 0),
-    (198, 186, 0), (196, 186, 1), (194, 187, 2), (193, 187, 4), (191, 188, 6), (189, 189, 9),
-    (188, 189, 13), (186, 190, 16), (184, 190, 20), (182, 191, 23), (181, 192, 26), (179, 192, 29),
-    (177, 193, 32), (175, 193, 35), (174, 194, 37), (172, 194, 39), (170, 195, 41), (168, 195, 43),
-    (166, 196, 44), (165, 196, 46), (163, 197, 47), (161, 197, 49), (159, 198, 50), (157, 199, 51),
-    (155, 199, 53), (153, 200, 54), (150, 200, 56), (148, 201, 57), (146, 201, 59), (144, 202, 61),
-    (141, 202, 64), (139, 202, 66), (137, 203, 69), (134, 203, 72), (132, 203, 75), (129, 204, 78),
-    (127, 204, 81), (124, 204, 84), (122, 204, 87), (119, 204, 90), (116, 205, 94), (114, 205, 97),
-    (111, 205, 100), (108, 205, 103), (105, 205, 107), (102, 205, 110), (100, 205, 114), (97, 204, 118),
-    (94, 204, 121), (91, 204, 125), (89, 204, 129), (86, 204, 132), (83, 203, 136), (81, 203, 139),
-    (78, 203, 143), (75, 202, 147), (72, 202, 150), (70, 201, 154), (67, 201, 157), (64, 200, 161),
-    (62, 200, 164), (59, 199, 167), (57, 199, 171), (55, 198, 174), (53, 198, 178), (51, 197, 181),
-    (49, 196, 184), (47, 196, 187), (45, 195, 190), (44, 195, 194), (42, 194, 197), (41, 193, 200),
-    (40, 193, 203), (39, 192, 206), (39, 191, 208), (39, 191, 211), (39, 190, 214), (40, 190, 217),
-    (40, 189, 219), (41, 188, 222), (42, 188, 225), (43, 188, 227), (45, 187, 230), (46, 187, 232),
-    (48, 186, 234), (50, 186, 236), (53, 186, 239), (55, 186, 241), (57, 186, 243), (59, 186, 245),
-    (61, 186, 247), (62, 186, 249), (62, 187, 251), (62, 188, 252), (61, 189, 254), (60, 190, 254),
-    (59, 192, 254), (58, 193, 254), (57, 194, 254), (56, 196, 254), (55, 197, 254), (53, 199, 254),
-    (52, 200, 254), (51, 202, 254), (50, 203, 253), (49, 205, 253), (49, 206, 253), (48, 208, 252),
-    (47, 210, 251), (46, 211, 251), (46, 213, 250), (45, 214, 249), (44, 216, 249), (43, 217, 248),
-    (42, 219, 247), (42, 221, 247), (41, 222, 246), (40, 224, 246), (40, 225, 245), (39, 227, 245),
-    (38, 229, 245), (38, 230, 245), (37, 232, 245), (36, 233, 245), (35, 235, 245), (34, 236, 245),
-    (33, 238, 245), (32, 239, 246), (31, 241, 246), (30, 242, 246), (28, 244, 247), (27, 245, 247),
-    (26, 247, 248), (24, 248, 248), (22, 249, 249), (21, 251, 249)]
-colormap_parula_rgb = [(c[2], c[1], c[0]) for c in colormap_parula_bgr]
+magma = colormap_magma_rgb
 
 colormap_pastel_bgr = [
     (0, 0, 0), (0, 0, 3), (0, 0, 7), (0, 0, 10), (1, 0, 13), (1, 0, 16),
@@ -682,6 +646,7 @@ colormap_pastel_bgr = [
     (192, 255, 249), (199, 255, 250), (206, 255, 250), (213, 255, 251), (220, 255, 252), (227, 255, 252),
     (234, 255, 253), (241, 255, 254), (248, 255, 254), (255, 255, 255)]
 colormap_pastel_rgb = [(c[2], c[1], c[0]) for c in colormap_pastel_bgr]
+pastel = colormap_pastel_rgb
 
 colormap_plasma_bgr = [
     (135, 8, 13), (136, 7, 16), (137, 7, 19), (138, 7, 22), (140, 6, 25), (141, 6, 27),
@@ -728,6 +693,7 @@ colormap_plasma_bgr = [
     (38, 233, 245), (39, 235, 245), (39, 237, 244), (39, 238, 243), (39, 240, 243), (39, 242, 242),
     (38, 244, 241), (37, 245, 241), (36, 247, 240), (33, 249, 240)]
 colormap_plasma_rgb = [(c[2], c[1], c[0]) for c in colormap_plasma_bgr]
+plasma = colormap_plasma_rgb
 
 colormap_sepia_bgr = [
     (0, 0, 0), (1, 1, 2), (2, 3, 4), (3, 4, 6), (4, 5, 7), (6, 7, 9),
@@ -774,6 +740,7 @@ colormap_sepia_bgr = [
     (242, 244, 247), (243, 245, 248), (245, 247, 249), (246, 248, 250), (248, 249, 251), (249, 250, 252),
     (251, 251, 252), (252, 253, 253), (254, 254, 254), (255, 255, 255)]
 colormap_sepia_rgb = [(c[2], c[1], c[0]) for c in colormap_sepia_bgr]
+sepia = colormap_sepia_rgb
 
 colormap_temperature_bgr = [
     (217, 0, 36), (219, 2, 35), (221, 4, 35), (223, 6, 34), (225, 8, 33), (227, 10, 32),
@@ -820,6 +787,7 @@ colormap_temperature_bgr = [
     (42, 13, 196), (41, 12, 193), (40, 10, 190), (39, 9, 186), (38, 7, 183), (37, 6, 179),
     (36, 4, 176), (35, 3, 173), (34, 1, 169), (33, 0, 166)]
 colormap_temperature_rgb = [(c[2], c[1], c[0]) for c in colormap_temperature_bgr]
+temperature = colormap_temperature_rgb
 
 colormap_thermal_bgr = [
     (0, 0, 0), (4, 1, 3), (8, 2, 5), (12, 2, 8), (15, 3, 10), (18, 4, 13),
@@ -866,7 +834,7 @@ colormap_thermal_bgr = [
     (223, 248, 241), (227, 249, 243), (230, 249, 244), (234, 250, 246), (237, 251, 247), (241, 252, 249),
     (244, 253, 250), (248, 253, 252), (251, 254, 253), (255, 255, 255)]
 colormap_thermal_rgb = [(c[2], c[1], c[0]) for c in colormap_thermal_bgr]
-
+thermal = colormap_thermal_rgb
 
 # Google's rainbow "Turbo" colormap, see
 # https://ai.googleblog.com/2019/08/turbo-improved-rainbow-colormap-for.html
@@ -917,7 +885,7 @@ colormap_turbo_bgr = [
     (1, 7, 132), (2, 6, 129), (2, 5, 125), (2, 4, 122)
 ]
 colormap_turbo_rgb = [(c[2], c[1], c[0]) for c in colormap_turbo_bgr]
-
+turbo = colormap_turbo_rgb
 
 colormap_viridis_bgr = [
     (84, 1, 68), (86, 2, 68), (87, 4, 69), (89, 5, 69), (90, 7, 70), (92, 8, 70),
@@ -964,3 +932,4 @@ colormap_viridis_bgr = [
     (25, 228, 231), (26, 229, 234), (27, 229, 236), (28, 229, 239), (29, 229, 241), (30, 230, 244),
     (32, 230, 246), (33, 230, 248), (35, 231, 251), (37, 231, 253)]
 colormap_viridis_rgb = [(c[2], c[1], c[0]) for c in colormap_viridis_bgr]
+viridis = colormap_viridis_rgb
